[MOAB-dev] r4650 - MOAB/trunk/src/moab
tautges at mcs.anl.gov
tautges at mcs.anl.gov
Fri Mar 25 13:13:00 CDT 2011
Author: tautges
Date: 2011-03-25 13:13:00 -0500 (Fri, 25 Mar 2011)
New Revision: 4650
Modified:
MOAB/trunk/src/moab/GeomTopoTool.hpp
Log:
Backing out this last change, didn't mean to commit it.
Modified: MOAB/trunk/src/moab/GeomTopoTool.hpp
===================================================================
--- MOAB/trunk/src/moab/GeomTopoTool.hpp 2011-03-25 18:04:36 UTC (rev 4649)
+++ MOAB/trunk/src/moab/GeomTopoTool.hpp 2011-03-25 18:13:00 UTC (rev 4650)
@@ -45,14 +45,14 @@
//!\return MB_MULTIPLE_ENTITIES_FOUND if surface already has a forward volume.
//! MB_SUCCESS if successful
//! otherwise whatever internal error code occured.
- ErrorCode set_sense( EntityHandle entity,
- EntityHandle wrt_entity,
- int sense);
+ ErrorCode set_sense( EntityHandle surface,
+ EntityHandle volume,
+ bool forward );
- //! Get the sense of entity with respect to wrt_entity
+ //! Get the sense of a lower-dim entity with respect to an upper-dim entity
//! Returns MB_ENTITY_NOT_FOUND if no relationship found
- ErrorCode get_sense( EntityHandle entity,
- EntityHandle wrt_entity,
+ ErrorCode get_sense( EntityHandle lower,
+ EntityHandle upper,
bool& forward );
#endif
//! Store sense of entity relative to wrt_entity.
@@ -74,9 +74,8 @@
std::vector<EntityHandle> &faces,
std::vector<int> &senses);
- //! Set senses of entity with respect to wrt_entities
- ErrorCode set_senses(EntityHandle entity,
- std::vector<EntityHandle> &wrt_entities,
+ ErrorCode set_senses(EntityHandle edge,
+ std::vector<EntityHandle> &faces,
std::vector<int> &senses);
#endif
ErrorCode get_senses (EntityHandle entity,
More information about the moab-dev
mailing list